@@ -1,7 +1,7 @@
 #ifndef GLITE_LB_CONTEXT_INT_H
 #define GLITE_LB_CONTEXT_INT_H
 
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/interface/context-int.h,v 1.65 2012/08/01 13:02:29 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -73,7 +73,7 @@ typedef struct _edg_wll_ConnProxy  edg_wll_ConnProxy;
 
 
 /* !!! if adding something malloc-able, update edg_wll_FreeContext too !!! */
-glite_lb_padded_struct(_edg_wll_Context,150,
+glite_lb_padded_struct(_edg_wll_Context,200,
 /// XXX: branch value: glite_lb_padded_struct(_edg_wll_Context,120,
 /* Error handling */
 	int		errCode;	/* recent error code */
@@ -188,6 +188,16 @@ glite_lb_padded_struct(_edg_wll_Context,150,
 	char 		*authz_policy_file;
 
 	char		*html_header_file;
+		       
+	_edg_wll_id_mapping	id_mapping;
+
+	char            *p_event_file_prefix;
+
+	char            *p_il_sock;
+        int             async_registrations;
+
+	char		*p_lbproxy_servername;
+	unsigned int	p_lbproxy_servername_port;
 )
 
 /* to be used internally: set, update and and clear the error information in 
