@@ -1,7 +1,7 @@
 #ifndef GLITE_LB_EVENTS_PARSE_H
 #define GLITE_LB_EVENTS_PARSE_H
 
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/interface/events_parse.h,v 1.11 2012/06/13 21:06:23 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -110,14 +110,6 @@ extern edg_wll_LogLine edg_wll_UnparseNotifEvent(
 	edg_wll_Event *	event
 );
 
-extern int edg_wll_TagListParse(
-	const char *src,
-	edg_wll_TagValue **list);
-
-extern int edg_wll_TagListCompare(
-	edg_wll_TagValue *a,
-	 edg_wll_TagValue *b);
-
 #ifdef __cplusplus
 }
 #endif
